Adafruit CircuitPython API Reference
====================================

Welcome to the API reference documentation for Adafruit CircuitPython.
This contains low-level API reference docs which may link out to separate
*"getting started"* guides. `Adafruit <https://adafruit.com>`_ has many
excellent tutorials available through the
`Adafruit Learning System <https://learn.adafruit.com/>`_.

.. include:: ../README.rst

.. _contents:

Full Table of Contents
----------------------

.. toctree::
   :maxdepth: 3
   :caption: API and Usage

   ../shared-bindings/index.rst
   supported_ports.rst
   troubleshooting.rst
   drivers.rst

.. toctree::
   :maxdepth: 1
   :caption: Design and porting reference

   design_guide
   porting
   common_hal

.. toctree::
   :maxdepth: 2
   :caption: MicroPython specific

   library/index.rst
   reference/glossary.rst

.. toctree::
   :maxdepth: 1
   :caption: About the project

   ../README
   ../CONTRIBUTING
   ../BUILDING
   ../CODE_OF_CONDUCT
   ../license.rst
   ../WEBUSB_README

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
